#!/usr/bin/python3

# from feii.log import Log
# from feii.config import Config
# from feii.init import Init
from feii.structure import Structure

class FixError(Structure):
  def not_ilm_retry_index_and_check(self):
    if not self.ilm_retry_index_and_check():
      self.logger.error("Failed ilm retry to next index [{0}]".format( self.index ))

  def remove_block_index_and_check(self):
    self.remove_block_index()
    return self.check_remove_block_index()

  def not_remove_block_index_and_check(self):
    if not self.remove_block_index_and_check():
      self.logger.error("Failed remove cluster block to index [{0}]".format( self.index ))
      return True

  def fix_error_ilm_last_index(self):
    for index in self.error_ilm_last_indices:
      self.index = index['index']

      if index['error.type'] == "process_cluster_event_timeout_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "illegal_state_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "index_closed_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "illegal_argument_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "resource_already_exists_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "cluster_block_exception":
        if self.not_remove_block_index_and_check():
          continue
        self.not_ilm_retry_index_and_check()

  def fix_error_ilm_not_hot_phase_index(self):
    for index in self.error_ilm_not_hot_phase_indices:
      self.index = index['index']

      if index['error.type'] == "process_cluster_event_timeout_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "illegal_state_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "index_closed_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "illegal_argument_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "resource_already_exists_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "cluster_block_exception":
        if self.not_remove_block_index_and_check():
          continue
        self.not_ilm_retry_index_and_check()

  def fix_error_ilm_not_last_index(self):
    for index in self.error_ilm_not_last_indices:
      self.index = index['index']

      if index['error.type'] == "process_cluster_event_timeout_exception":
        self.not_next_step_for_index_and_check()

      if index['error.type'] == "illegal_state_exception":
        self.not_next_step_for_index_and_check()

      if index['error.type'] == "index_closed_exception":
        self.not_next_step_for_index_and_check()

      if index['error.type'] == "illegal_argument_exception":
        self.not_next_step_for_index_and_check()

      if index['error.type'] == "resource_already_exists_exception":
        self.not_next_step_for_index_and_check()

      if index['error.type'] == "cluster_block_exception":
        if self.not_remove_block_index_and_check():
          continue
        self.not_next_step_for_index_and_check()

  def fix_error_ilm_shrink_index(self):
    for index in self.error_ilm_shrink_indices:
      self.index = index['index']

      if index['error.type'] == "process_cluster_event_timeout_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "index_closed_exception":
        self.not_ilm_retry_index_and_check()

      if index['error.type'] == "null_pointer_exception":
        self.not_ilm_retry_index_and_check()

  def fix_error_ilm_last_index_in_check_mode(self):
    for index in self.error_ilm_last_indices:
      self.logger.warning("[check_mode] Fix ilm error [{0}] for index [{1}]".format( index['error.type'], index['index'] ))

  def fix_error_ilm_not_hot_phase_index_in_check_mode(self):
    for index in self.error_ilm_not_hot_phase_indices:
      self.logger.warning("[check_mode] Fix ilm error [{0}] for index [{1}]".format( index['error.type'], index['index'] ))

  def fix_error_ilm_not_last_index_in_check_mode(self):
    for index in self.error_ilm_not_last_indices:
      self.logger.warning("[check_mode] Fix ilm error [{0}] for index [{1}]".format( index['error.type'], index['index'] ))

  def fix_error_ilm_shrink_index_in_check_mode(self):
    for index in self.error_ilm_shrink_indices:
      self.logger.warning("[check_mode] Fix ilm error [{0}] for index [{1}]".format( index['error.type'], index['index'] ))



#!/usr/bin/python3

import click
from feii.cli import DeleteCLI

@click.command(
  cls=DeleteCLI,
  short_help='Deletion of empty indexes.',
  epilog="Run 'feii delete COMMAND --help' for more information on a command."
)
def cli():
  """Deletion of empty indexes"""



#!/usr/bin/python3

# import sys
import logging
from os import path, remove

class Log:
  def __init__(self,
    log_file_name: str = 'feii.log'
  ):
    super().__init__()
    self.log_file_name = log_file_name
    self.logger = logging.getLogger()
    self.log_file_format = logging.Formatter('[%(asctime)s] %(levelname)s - %(message)s')

  def get_file_handler(self):
    self.file_handler = logging.FileHandler(self.log_file_name)
    self.file_handler.setFormatter(self.log_file_format)

  def get_stream_handler(self):
    self.stream_handler = logging.StreamHandler()
    self.stream_handler.setFormatter(self.log_file_format)

  def get_logger(self):
    self.logger.setLevel(logging.DEBUG)
    self.logger.addHandler(self.file_handler)
    self.logger.addHandler(self.stream_handler)

  def remove_old_log_file(self):
    if path.isfile(self.log_file_name):
      remove(self.log_file_name)

  def logging_level_critical(self, level):
    if level == 'critical' or level == 'CRITICAL' or level == '=critical' or level == '=CRITICAL':
      self.logger.setLevel(logging.CRITICAL)

  def logging_level_error(self, level):
    if level == 'error' or level == 'ERROR' or level == '=error' or level == '=ERROR':
      self.logger.setLevel(logging.ERROR)

  def logging_level_warning(self, level):
    if level == 'warning' or level == 'WARNING' or level == '=warning' or level == '=WARNING':
      self.logger.setLevel(logging.WARNING)

  def logging_level_info(self, level):
    if level == 'info' or level == 'INFO' or level == '=info' or level == '=INFO':
      self.logger.setLevel(logging.INFO)

  def logging_level_debug(self, level):
    if level == 'debug' or level == 'DEBUG' or level == '=debug' or level == '=DEBUG':
      self.logger.setLevel(logging.DEBUG)

  def logging_level_notset(self, level):
    if level == 'notset' or level == 'NOTSET' or level == '=notset' or level == '=NOTSET':
      self.logger.setLevel(logging.NOTSET)



#!/usr/bin/python3

# import requests
# from feii.config import Config

class Request:
  def __init__(self,
    request: str = '',
  ):
    super().__init__()
    self.request = request

  def status_request(self):
    return self.request.status_code == 200 or 201



#!/usr/bin/python3

import click
from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables_for_shards, generating_variables_for_unassigned_shard
from feii.mapping import Mapping

class_mapping = Mapping()
class_mapping.logger = class_log.logger

def start_fix_mapping_error_in_unassigned_shards(check_mode):
  if not check_mode:
    class_mapping.fix_mapping_error_in_unassigned_shards()

def start_check_mode_fix_mapping_error_in_unassigned_shards(check_mode):
  if check_mode:
    class_mapping.fix_mapping_error_in_unassigned_shards_check_mode()

@click.command(short_help='Starts fixing the mapping error in unassigned shards.')
@click.option(
  '-c', '--check-mode',
  is_flag=True,
  expose_value=True,
  help='Only displaying actions, without performing them.'
)
@click.option(
  '-l', '--log-level',
  default='info',
  show_default=True,
  expose_value=True,
  help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
)
@click.option(
  '-P', '--path-to-file',
  default='',
  expose_value=True,
  help='path'
)
def cli(check_mode, log_level, path_to_file):
  """Starts fixing the mapping error in unassigned shards"""

  logging_level(log_level)
  class_log.logger.info("Starts fixing the mapping error in unassigned shards")

  updating_variables(path_to_file)

  generating_variables_for_shards()
  generating_variables_for_unassigned_shard()

  start_fix_mapping_error_in_unassigned_shards(check_mode)
  start_check_mode_fix_mapping_error_in_unassigned_shards(check_mode)

if __name__ == "__main__":
  cli()



#!/usr/bin/python3

# import click
from feii.log import Log
from feii.config import Config
from feii.init import Init
from feii.structure import Structure
from feii.path_to_file import PathToFile

class_config = Config
class_path_to_file = PathToFile()
class_structure = Structure()
class_log = Log()

class_log.remove_old_log_file()
class_log.get_file_handler()
class_log.get_stream_handler()
class_log.get_logger()

def updating_variables(path_to_file):
  class_config.path = path_to_file
  class_path_to_file.get_config()

def logging_level(level):
  if level:
    class_log.logging_level_critical(level)
    class_log.logging_level_error(level)
    class_log.logging_level_warning(level)
    class_log.logging_level_info(level)
    class_log.logging_level_debug(level)
    class_log.logging_level_notset(level)

def generating_variables_for_indices():
  class_config.index_pools = Init(count = 5).list_pools()
  class_config.ilm_list = class_config.index_pools[3].json()
  class_config.settings_list = class_config.index_pools[2].json()
  class_config.alias_list = class_config.index_pools[1].json()
  class_config.ilm_policy = class_config.index_pools[5].json()

  class_structure.logger = class_log.logger

  class_structure.creating_array_index_details_in_open()
  class_structure.creating_array_index_to_remove()
  class_structure.remove_invalid_index_name_in_array()
  class_structure.creating_array_indices()
  class_structure.creating_array_max_indices()

  del(class_structure.index_details)
  del(class_structure.index_to_remove)

def generating_variables_for_shards():
  class_config.index_pools = Init(count = 5).list_pools()
  class_config.ilm_list = class_config.index_pools[3].json()
  class_config.settings_list = class_config.index_pools[2].json()
  class_config.alias_list = class_config.index_pools[1].json()

  class_structure.logger = class_log.logger

  class_structure.creating_array_shard_details_in_primary()
  class_structure.creating_array_shard_not_duplicates()
  class_structure.creating_array_shard_to_remove()
  class_structure.remove_invalid_shard_name_in_array()
  class_structure.creating_array_shards()

  del(class_structure.shard_details)
  del(class_structure.shards_details)
  del(class_structure.shard_to_remove)

def generating_variables_for_unassigned_shard():
  class_structure.creating_array_unassigned_shard()

def generating_variables_for_delete():
  class_structure.creating_array_last_index()
  class_structure.creating_array_not_last_index()

  class_structure.creating_array_delete_index()

def generating_variables_for_alias():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_shrink_index()

  class_structure.creating_array_no_alias_in_index()
  class_structure.creating_array_no_necessary_alias_in_index()
  class_structure.creating_array_no_shrink_alias_in_index()

def generating_variables_for_alias_not_shrink():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_shrink_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.shrink_indices )

  class_structure.creating_array_no_alias_in_index()
  class_structure.creating_array_no_necessary_alias_in_index()

def generating_variables_for_write_alias():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_shrink_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.shrink_indices )

  class_structure.creating_array_not_last_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.not_last_indices )

  class_structure.creating_array_no_alias_in_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.indices_no_alias )

  class_structure.creating_array_no_necessary_alias_in_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.indices_no_necessary_alias )

  class_structure.creating_array_not_write_in_index()

def generating_variables_for_rollover():
  class_structure.creating_array_invalid_size_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.invalid_size_indices )

def generating_variables_for_rollover_next_step():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_not_hot_box_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.not_hot_box_indices )

  class_structure.creating_array_not_hot_phase_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.not_hot_phase_indices )

  class_structure.creating_array_shrink_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.shrink_indices )

  class_structure.creating_array_last_index()
  class_structure.creating_array_not_last_index()
  class_structure.creating_array_last_shrink_index()

def generating_variables_for_update():
  class_structure.creating_array_last_index()
  class_structure.creating_array_not_last_index()

  class_structure.creating_array_timeout_last_index()
  class_structure.creating_array_timeout_not_last_index()

def generating_variables_for_fix_error():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_error_ilm_index()
  class_structure.creating_array_error_ilm_shrink_index()
  class_structure.remove_invalid_error_ilm_indexes_in_array( class_structure.error_ilm_shrink_indices )
  class_structure.creating_array_error_ilm_last_indices()

  class_structure.remove_invalid_error_ilm_indexes_in_array( class_structure.error_ilm_last_indices )
  class_structure.creating_array_error_ilm_not_hot_phase_indices()

  class_structure.remove_invalid_error_ilm_indexes_in_array( class_structure.error_ilm_not_hot_phase_indices )
  class_structure.creating_array_error_ilm_not_last_indices()

def generating_variables_for_write_close_indices():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_not_last_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.not_last_indices )

  class_structure.creating_array_last_index()
  class_structure.creating_array_not_write_in_index()

  class_structure.remove_invalid_indexes_in_array( class_structure.indices_not_write )
  class_structure.creating_array_write_false_in_index()

def generating_variables_for_update_ilm_policy():
  class_structure.creating_array_unmanaged_index()
  class_structure.remove_invalid_indexes_in_array( class_structure.unmanaged_indices )

  class_structure.creating_array_last_index()
  class_structure.creating_array_not_last_index()

def deleting_unnecessary_variables():
  del(class_structure.invalid_size_indices)
  del(class_structure.unmanaged_indices)
  del(class_structure.not_hot_box_indices)
  del(class_structure.not_hot_phase_indices)



#!/usr/bin/python3

import click
from feii.main import class_structure, class_log, logging_level, updating_variables
from feii.cluster import Cluster

class_cluster = Cluster()
class_cluster.logger = class_log.logger

def start_retry_failed():
    class_cluster.retry_failed()
    class_cluster.check_retry_failed()

@click.command(short_help='Starts retry failed indexes.')
@click.option(
  '-l', '--log-level',
  default='info',
  show_default=True,
  expose_value=True,
  help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
)
@click.option(
  '-P', '--path-to-file',
  default='',
  expose_value=True,
  help='path'
)
def cli(log_level, path_to_file):
  """Starts retry failed indexes"""

  logging_level(log_level)
  class_log.logger.info("Starts retry failed indexes")

  updating_variables(path_to_file)

  start_retry_failed()

if __name__ == "__main__":
  cli()



#!/usr/bin/python3

# import re
# import requests
# from feii.log import Log
# from feii.config import Config
# from feii.request import Request
# from feii.init import Init
from feii.structure import Structure

class Update(Structure):
  def debug_detail_index(self):
    self.index = 'test-000001'
    self.index_docs_count = 0

  def failed_check_update_timeout_index(self):
    if not self.update_index_and_check():
      self.logger.error("Failed updating timeout index [{0}]".format( self.index ))
      self.logger.warning("Skip this index and continue with the following index")

  def update_timeout_for_last_indexes(self):
    for index in self.timeout_last_indices:
      self.index = index['index']
      self.data = { "settings": { "index.unassigned.node_left.delayed_timeout": self.HOT_DELAYED_TIMEOUT } }

      self.failed_check_update_timeout_index()

  def update_timeout_for_not_last_indexes(self):
    for index in self.timeout_not_last_indices:
      self.index = index['index']
      self.data = { "settings": { "index.unassigned.node_left.delayed_timeout": self.COLD_DELAYED_TIMEOUT } }

      self.failed_check_update_timeout_index()

  def update_timeout_for_last_indexes_check_mode(self):
    for index in self.timeout_last_indices:
      self.logger.warning("[check_mode] Updating last index [{0}] settings (delayed_timeout - {1})".format( index['index'], self.HOT_DELAYED_TIMEOUT ))

  def update_timeout_for_not_last_indexes_check_mode(self):
    for index in self.timeout_not_last_indices:
      self.logger.warning("[check_mode] Updating not last index [{0}] settings (delayed_timeout - {1})".format( index['index'], self.COLD_DELAYED_TIMEOUT ))



#!/usr/bin/python3

# import re
import requests
# from feii.log import Log
from feii.config import Config
from feii.request import Request
# from feii.function import Function

class Ilm(Config, Request):
  def __init__(self,
    ilm_info_for_index: str = {},
    age_ilm_policies: str = {}
  ):
    super().__init__()
    self.ilm_info_for_index = ilm_info_for_index
    self.age_ilm_policies = age_ilm_policies

  def debug_detail_index(self):
    self.alias = 'test'
    self.index = 'test-000001'

  def rollover_index(self):
    return requests.post("{0}/{1}/_rollover?master_timeout={2}".format( self.ELASTIC_URL, self.alias, self.MASTER_TIMEOUT ))

  def check_create_next_index(self):
    self.request = requests.get("{0}/{1}/_ilm/explain".format( self.ELASTIC_URL, self.next_index ))

  def check_rollover_index(self):
    if self.status_request():
      self.logger.info("Rollover index for alias [{0}], new index [{1}] is created".format( self.alias, self.next_index ))
      return True

  def ilm_retry_for_index(self):
    self.request = requests.post("{0}/{1}/_ilm/retry?master_timeout={2}".format( self.ELASTIC_URL, self.index, self.MASTER_TIMEOUT ))

  def check_ilm_retry_for_index(self):
    if self.status_request():
      self.logger.info("Retrying ILM for index [{0}] - True".format( self.index ))
      return True

  def current_ilm_info_for_index(self):
    self.request = requests.get("{0}/{1}/_ilm/explain".format( self.ELASTIC_URL, self.index )).json()

  def create_current_ilm_info_for_index(self):
    self.ilm_info_for_index['phase'] = self.request['indices'][self.index]['phase']
    self.ilm_info_for_index['action'] = self.request['indices'][self.index]['action']
    self.ilm_info_for_index['step'] = self.request['indices'][self.index]['step']

  def next_step_index_in_warm(self):
    self.data = { "current_step": { "phase": self.ilm_info_for_index['phase'], "action": self.ilm_info_for_index['action'], "name": self.ilm_info_for_index['step']}, "next_step": { "phase": "warm", "action": "set_priority", "name": "set_priority" } }

  def next_step_index_in_cold(self):
    self.data = { "current_step": { "phase": self.ilm_info_for_index['phase'], "action": self.ilm_info_for_index['action'], "name": self.ilm_info_for_index['step']}, "next_step": { "phase": "cold", "action": "set_priority", "name": "set_priority" } }

  def request_step_for_index(self):
    self.request = requests.post("{0}/_ilm/move/{1}?master_timeout={2}".format( self.ELASTIC_URL, self.index, self.MASTER_TIMEOUT ), json=self.data )

  def check_next_step_for_index(self):
    if self.status_request():
      self.logger.info("Next step ILM for index [{0}] - True".format( self.index ))
      return True

  def check_re_step_for_index(self):
    if self.status_request():
      self.logger.info("Re step ILM for index [{0}] - True".format( self.index ))
      return True

  def remove_block_index(self):
    data = { "index": { "blocks": { "read_only_allow_delete": False } } }
    self.request = requests.put("{0}/{1}/_settings?master_timeout={2}".format( self.ELASTIC_URL, self.index, self.MASTER_TIMEOUT ), json=data )

  def check_remove_block_index(self):
    if self.status_request():
      self.logger.info("Remove cluster block for index [{0}] - True".format( self.index ))
      return True

  def remove_ilm_policy(self):
    self.request = requests.post("{0}/{1}/_ilm/remove?master_timeout={2}".format( self.ELASTIC_URL, self.index, self.MASTER_TIMEOUT ))

  def check_remove_ilm_policy(self):
    if self.status_request():
      self.logger.info("Removing the ilm policy - True")
      return True

  def adding_new_ilm_policy(self):
    data = { "index.lifecycle.name": self.policy }
    self.request = requests.put("{0}/{1}/_settings?master_timeout={2}".format( self.ELASTIC_URL, self.index, self.MASTER_TIMEOUT ), json=data )

  def check_adding_new_ilm_policy(self):
    if self.status_request():
      self.logger.info("New ilm policy [{0}] added to index [{1}]".format( self.policy, self.index ))
      return True

  def creating_array_age_ilm_policy(self):
    for policy in Config.ilm_policy:
      if 'delete' in Config.ilm_policy[policy]['policy']['phases']:
        self.age_ilm_policies[policy] = { "policy.age": Config.ilm_policy[policy]['policy']['phases']['delete']['min_age'] }



#!/usr/bin/python3

import re
import requests
from feii.structure import Structure

class Policy(Structure):
  def __init__(self,
    index_or_alias: str = ""
  ):
    super().__init__()
    self.index_or_alias = index_or_alias

  def update_ilm_policy(self, set_index: str = '', set_alias: str = '', set_policy: str = ''):
    self.check_service_index()

    self.index = set_index
    self.alias = set_alias
    self.policy = set_policy

    self.check_on_alias()
    self.check_on_index()

    if self.index and not self.check_for_latest_index():
      self.logger.warning("The specified index [{0}] is not the last one".format( self.index ))
      self.find_latest_index()

    if self.alias:
      self.find_latest_index()

    self.remove_ilm_policy()
    self.check_remove_ilm_policy()

    self.adding_new_ilm_policy()
    self.check_adding_new_ilm_policy()

    self.creating_array_index_to_remove_by_ilm_policy()
    self.writing_to_service_index()
    self.check_writing_to_service_index()

  def update_ilm_policy_check_mode(self, set_index: str = '', set_alias: str = '', set_policy: str = ''):
    self.index = set_index
    self.alias = set_alias
    self.policy = set_policy

    self.check_on_alias()
    self.check_on_index()

    if self.index and not self.check_for_latest_index():
      self.logger.warning("The specified index [{0}] is not the last one".format( self.index ))
      self.find_latest_index()

    if self.alias:
      self.find_latest_index()

    self.logger.warning("[check_mode] Updating the index [{0}] policy on the [{1}]".format( self.index, self.policy ))

  def check_for_latest_index(self):
    for index in self.last_indices:
      if self.index == index['index']:
        return True

  def check_on_alias(self):
    if not self.index and self.alias:
      self.index_or_alias = re.sub(r'(shrink-)', '', self.alias)

  def check_on_index(self):
    if not self.alias and self.index:
      self.index_or_alias = re.sub(r'(shrink-)', '', self.index[:-7])

  def find_latest_index(self):
    for index in self.last_indices:
      if self.index_or_alias == index['index.alias']:
        self.index = index['index']

  def writing_to_service_index(self):
    if self.indices_to_remove_by_ilm_policy:
      data = { "indexes": self.indices_to_remove_by_ilm_policy, "policy": self.policy }
      self.request = requests.post("{0}/{1}/_doc/?timeout={2}".format( self.ELASTIC_URL,  self.SERVICE_INDEX, self.MASTER_TIMEOUT ), json=data )

  def check_writing_to_service_index(self):
    if self.indices_to_remove_by_ilm_policy and self.status_request():
      self.logger.info("The array of indexes is written to the service index [{0}]".format( self.SERVICE_INDEX))
      return True



#!/usr/bin/python3

# import re
# import requests
# from feii.log import Log
# from feii.config import Config
# from feii.init import Init
from feii.structure import Structure
# from feii.function import Function

class Write(Structure):
  def __init__(self,
    closed_indices: str = [],
  ):
    super().__init__()
    self.closed_indices = closed_indices

  def adding_no_write_to_array(self):
    for index in self.indices_not_write:
      self.closed_indices.append(index)

  def adding_disabled_write_to_array(self):
    for index in self.indices_write_false:
      self.closed_indices.append(index)

  def creating_new_index_for_writing(self):
    for index in self.closed_indices:
      self.index = index['index']
      self.alias = index['index.alias']

      if not self.create_new_index_and_check():
        self.logger.error("Failed create new index [{0}]".format( self.new_index_name ))
        self.logger.warning("Skip this index and continue with the following index")
        continue

      self.index = self.new_index_name
      if not self.add_write_enable_for_index_and_check():
        self.logger.error("Failed enable write to next index [{0}]".format( self.index ))
        self.logger.warning("Skip this index and continue with the following index")
        continue

  def no_write_last_indices_check_mode(self):
    for index in self.indices_not_write:
      self.logger.warning("[check_mode] Not write last index [{0}]".format( index['index'] ))

  def write_disabled_in_last_indices_check_mode(self):
    for index in self.indices_write_false:
      self.logger.warning("[check_mode] Write false last index [{0}]".format( index['index'] ))



#!/usr/bin/python3

import sys
import click
from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables_for_indices, generating_variables_for_update_ilm_policy, deleting_unnecessary_variables
from feii.policy import Policy

class_policy = Policy()
class_policy.logger = class_log.logger

def start_update_ilm_policy(check_mode, index, alias, policy):
  if not check_mode:
    class_policy.update_ilm_policy(index, alias, policy)

def start_check_mode_update_ilm_policy(check_mode, index, alias, policy):
  if check_mode:
    class_policy.update_ilm_policy_check_mode(index, alias, policy)

@click.command(short_help='Updating the ilm Policy.')
@click.option(
  '-c', '--check-mode',
  is_flag=True,
  expose_value=True,
  help='Only displaying actions, without performing them.'
)
@click.option(
  '-l', '--log-level',
  default='info',
  show_default=True,
  expose_value=True,
  help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
)
@click.option(
  '-P', '--path-to-file',
  default='',
  expose_value=True,
  help='path'
)
@click.option(
  '-i', '--index',
  default='',
  expose_value=True,
  help='Set the index name'
)
@click.option(
  '-a', '--alias',
  default='',
  expose_value=True,
  help='Set the alias name'
)
@click.option(
  '-p', '--policy',
  default='',
  expose_value=True,
  help='Set the ilm policy name'
)
def cli(check_mode, log_level, path_to_file, index, alias, policy):
  """Updating the ilm Policy"""

  logging_level(log_level)
  class_log.logger.info("Started updating the ilm Policy")

  if not index and not alias or not policy:
    sys.exit(class_log.logger.error("You need to specify an index or alias, as well as a policy"))

  if index and alias:
    sys.exit(class_log.logger.error("You need to specify either an index or an alias"))

  updating_variables(path_to_file)

  generating_variables_for_indices()
  generating_variables_for_update_ilm_policy()
  deleting_unnecessary_variables()

  if index and policy or alias and policy:
    start_update_ilm_policy(check_mode, index, alias, policy)
    start_check_mode_update_ilm_policy(check_mode, index, alias, policy)

if __name__ == "__main__":
  cli()
